<template>
    <div class="container">
        <div class="header">
            <div class="title">
                <i class="title-icon"></i>
                <span class="title-text">基础数据统计</span>
            </div>
            <i class="back-icon" @click="handleReset"></i>
        </div>
        <div class="table">
            <el-table
                :data="tableData"
                stripe
                v-loading="loading"
                @row-click="hanldeRowClick"
                @cell-click="handleCellClick"
                header-cell-class-name="custom-header-cell"
                cell-class-name="custom-cell"
            >
                <el-table-column label="序号" type="index" width="70" align="center">
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="name"
                    label="名称"
                    column-key="sectionManagement"
                >
                    <template v-slot="{row}">
                        <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
                        {{ row.name }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="roadCount"
                    column-key="sectionManagement"
                    label="路段数量"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.roadCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="tollGateCount"
                    column-key="3"
                    label="收费站"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.tollGateCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="serviceCount"
                    label="服务区"
                    column-key="4"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.serviceCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="interworkingCount"
                    label="互通"
                    column-key="1"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.interworkingCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="bridgeCount"
                    label="桥梁"
                    column-key="bridgeManagement"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.bridgeCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="tunnelCount"
                    column-key="tunnelManagement"
                    label="隧道"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.tunnelCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="culvertCount"
                    column-key="culvertManagement"
                    label="涵洞"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.culvertCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="workCount"
                    column-key="maintenanceWorkArea"
                    label="工区"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.workCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="carCount"
                    column-key="carManagement"
                    label="车辆"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.carCount) }}
                    </template>
                </el-table-column>
            </el-table>
            <div class="table-total">
                <span>{{ tableData.length + 1 }}</span>
                <span>总数</span>
                <span class="item">{{ utils.thousandBit(total.roadCount) || 0 }}</span>
                <span class="item">{{
                    utils.thousandBit(total.tollGateCount) || 0
                }}</span>
                <span class="item">{{ utils.thousandBit(total.serviceCount) || 0 }}</span>
                <span class="item">{{
                    utils.thousandBit(total.interworkingCount) || 0
                }}</span>
                <span class="item">{{ utils.thousandBit(total.bridgeCount) || 0 }}</span>
                <span class="item">{{ utils.thousandBit(total.tunnelCount) || 0 }}</span>
                <span class="item">{{ utils.thousandBit(total.culvertCount) || 0 }}</span>
                <span class="item">{{ utils.thousandBit(total.workCount) || 0 }}</span>
                <span class="item">{{ utils.thousandBit(total.carCount) || 0 }}</span>
            </div>
        </div>
        <div class="charts">
            <div class="charts-border">
                <div class="charts_title">
                    <i class="charts_title-icon"></i>
                    <!-- 基础信息数量分析 -->
                    <span class="charts_title-text">数量分析</span>
                </div>
                <div id="pie" style="height: 100%; width: 100%"></div>
            </div>
            <div class="charts-border">
                <div class="charts_title">
                    <i class="charts_title-icon clumn-icon"></i>
                    <!-- 各部门基础信息数量统计 -->
                    <span class="charts_title-text">数量统计</span>
                </div>
                <div id="column" style="height: 100%; width: 100%"></div>
            </div>
        </div>
    </div>
</template>

<script>
import utils from '@/utils' // thousandBit格式化千分位
const BigNumber = require('bignumber.js')
import * as echarts from 'echarts'
export default {
    name: 'BasicDataManagement',
    data() {
        return {
            tableData: [],
            data: [],
            loading: false,
            pathName: '',
            type: '',
            total: {},
            utils: utils,
        }
    },
    created() {
        this.loadData()
    },
    watch: {
        tableData(newVal) {
            this.total.roadCount = this.calculation('roadCount', newVal)
            this.total.tollGateCount = this.calculation('tollGateCount', newVal)
            this.total.serviceCount = this.calculation('serviceCount', newVal)
            this.total.interworkingCount = this.calculation('interworkingCount', newVal)
            this.total.bridgeCount = this.calculation('bridgeCount', newVal)
            this.total.tunnelCount = this.calculation('tunnelCount', newVal)
            this.total.culvertCount = this.calculation('culvertCount', newVal)
            this.total.workCount = this.calculation('workCount', newVal)
            this.total.carCount = this.calculation('carCount', newVal)
            this.pieCharts(this.total)
            this.cloumnCharts(newVal)
        },
    },
    methods: {
        calculation(key, arr) {
            let total = 0
            if (!key || arr.length === 0) return total
            arr.forEach((item) => {
                total += parseInt(item[key])
            })
            return total
        },
        handleReset() {
            let length = this.data.length - 1
            if (length === 0) return
            this.tableData = this.data[this.data.length - 2]
            this.data.splice(length, 1)
        },
        hanldeRowClick(row) {
            if (row.chirldren.length == 0 && row.roadSegmentId) {
                return this.$router.push({
                    name: this.pathName,
                    params: {
                        value: row,
                        type: this.type,
                    },
                })
            }
            this.tableData = row.chirldren
            this.data.push(row.chirldren)
        },
        handleCellClick(row, column) {
            if (
                column.columnKey == '1' ||
                column.columnKey == '3' ||
                column.columnKey == '4'
            ) {
                this.type = column.columnKey
                this.pathName = 'roadsideFacilitiesManagement'
            } else {
                this.pathName = column.columnKey
            }
        },
        loadData() {
            this.loading = true
            this.$http
                .post('${yhxt}/bizBridgeInformation/v1/getBridgeCountVo')
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
        pieCharts(obj) {
            var chartDom = document.getElementById('pie')
            var myChart = echarts.init(chartDom)
            let data = [
                {
                    name: '路段数量',
                    value: obj.roadCount || 0,
                },
                {
                    name: '收费站',
                    value: obj.tollGateCount || 0,
                },
                {
                    name: '服务区',
                    value: obj.serviceCount || 0,
                },
                {
                    name: '互通',
                    value: obj.interworkingCount || 0,
                },
                {
                    name: '桥梁',
                    value: obj.bridgeCount || 0,
                },
                {
                    name: '隧道',
                    value: obj.tunnelCount || 0,
                },
                {
                    name: '涵洞',
                    value: obj.culvertCount || 0,
                },
                {
                    name: '工区',
                    value: obj.workCount || 0,
                },
                {
                    name: '车辆',
                    value: obj.carCount || 0,
                },
            ]
            var option
            let total = new BigNumber(0)
            data.forEach((item) => {
                total = total.plus(item.value)
            })
            // let formatNumber = num =>
            //   num.toString().replace(/(?=(\B)(\d{3})+$)/g, ',')
            option = {
                title: [
                    {
                        text: `{name|总数量}\n{val|${this.utils.thousandBit(total)}}`,
                        top: 'center',
                        left: 'center',
                        textStyle: {
                            rich: {
                                name: {
                                    fontSize: 14,
                                    color: '#fff',
                                    padding: [10, 0],
                                },
                                val: {
                                    fontSize: 32,
                                    fontWeight: 'bold',
                                    color: '#fff',
                                },
                            },
                        },
                    },
                ],
                tooltip: {
                    trigger: 'item',
                    formatter: (a) => {
                        return `${a.marker} ${a.data.name} ${a.data.value}个 ${a.percent}%`
                    },
                },
                color: [
                    '#5b8ff9',
                    '#5ad8a6',
                    '#5d7092',
                    '#f6bd16',
                    '#6f5ef9',
                    '#6dc8ec',
                    '#945fb9',
                    '#ff9845',
                    '#1e9493',
                ],
                legend: {
                    icon: 'circle',
                    orient: 'vertical',
                    right: 25,
                    top: 'center',
                    bottom: 20,
                    textStyle: {
                        color: '#ccc',
                    },
                },
                series: [
                    {
                        type: 'pie',
                        radius: ['40%', '60%'],
                        // center: ['45%', '50%'],
                        data: data,
                        label: {
                            alignTo: 'edge',
                            formatter: (a) => {
                                return `{percent|${a.percent}%}`
                            },
                            minMargin: 5,
                            edgeDistance: '15%',
                            rich: {
                                percent: {
                                    fontSize: 15,
                                    color: '#fff',
                                },
                            },
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
        cloumnCharts(data) {
            var chartDom = document.getElementById('column')
            var myChart = echarts.init(chartDom)
            var option
            let xData = []
            let roadData = []
            let tollGateData = []
            let serviceData = []
            let interData = []
            let bridgeData = []
            let tunnelData = []
            let culvertData = []
            let workData = []
            let carData = []
            data.forEach((item) => {
                xData.push(item.name)
                roadData.push(item.roadCount)
                tollGateData.push(item.tollGateCount)
                serviceData.push(item.serviceCount)
                interData.push(item.interworkingCount)
                bridgeData.push(item.bridgeCount)
                tunnelData.push(item.tunnelCount)
                culvertData.push(item.culvertCount)
                workData.push(item.workCount)
                carData.push(item.carCount)
            })
            option = {
                title: {
                    textStyle: {
                        color: '#fff',
                    },
                },
                grid: {
                    top: '20%',
                    left: '10%',
                    right: '10%',
                    bottom: '20%',
                },
                legend: {
                    itemHeight: 10,
                    itemWidth: 10,
                    bottom: 'bottom',
                    bottom: '8%',
                    textStyle: {
                        color: '#fff',
                    },
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'none',
                    },
                },
                color: [
                    '#5b8ff9',
                    '#5ad8a6',
                    '#5d7092',
                    '#f6bd16',
                    '#6f5ef9',
                    '#6dc8ec',
                    '#945fb9',
                    '#ff9845',
                    '#1e9493',
                ],
                xAxis: {
                    type: 'category',
                    data: xData,
                    axisLabel: {
                        fontSize: 14,
                        color: '#B8C2CC',
                    },
                    axisTick: {
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                yAxis: {
                    name: '单位：个',
                    nameTextStyle: {
                        color: '#B8C2CC',
                        nameLocation: 'start',
                        fontSize: 18,
                        fontWeight: 700,
                    },
                    type: 'value',
                    splitLine: {show: false}, //去除网格线
                    axisLabel: {
                        textStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisTick: {
                        //y轴刻度线
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        //y轴
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                series: [
                    {
                        name: '路段数量',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: roadData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '收费站',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: tollGateData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '服务区',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: serviceData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '互通',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: interData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '桥梁',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: bridgeData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '隧道',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: tunnelData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '涵洞',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: culvertData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '工区',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: workData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        name: '车辆',
                        type: 'bar',
                        stack: 'Ad',
                        barWidth: '15%',
                        data: carData,
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-date-editor {
    background-color: #103c5d;
    border: none;
}
/deep/ .el-range-separator {
    color: #fff;
}
/deep/ .el-table th.is-leaf {
    background-color: transparent !important;
}
/deep/ .el-table__row {
    background-color: #0b426e !important;
}
/deep/ .el-table__row--striped {
    background-color: #124873 !important;
}
/deep/ .el-table__header-wrapper {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
}
/deep/ .el-table__body-wrapper {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}
/deep/ .el-table {
    background-color: transparent;
}
.container {
    padding: 30px;
    overflow: auto;
    box-sizing: border-box;

    .header {
        height: 59px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        border-bottom: 1px solid #4d7faf;
        .title {
            display: flex;
            height: 34px;
            align-items: center;
            .title-icon {
                display: block;
                width: 28px;
                height: 28px;
                background-image: url('../../assets/img/icon-标题@2x.png');
                background-size: 100% 100%;
            }
            .title-text {
                margin-left: 5px;
                height: 34px;
                font-size: 26px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 34px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
        .back-icon {
            margin-right: 10px;
            cursor: pointer;
            display: block;
            width: 40px;
            height: 40px;
            background-size: 100% 100%;
            background-image: url(../../assets//img/icon-返回@2x.png);
        }
    }
    .table {
        margin-top: 32px;
        width: 100%;
        /deep/ .custom-header-cell {
            background-color: #145080 !important;
            padding: 15px 0;
            .cell {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .custom-cell {
            padding: 15px 0;
            cursor: pointer;
            .cell,
            div {
                font-size: 16px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 400;
                color: #e5f2ff;
            }
        }
        .table-total {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 64px;
            background-color: #145080;
            border-radius: 10px;
            margin-top: 8px;
            span {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
                text-align: center;
                &:nth-child(1) {
                    width: 70px;
                }
                &:not(:nth-child(1)) {
                    flex: 1;
                }
            }
        }
    }
    .charts {
        margin-top: 32px;
        display: flex;
        .charts-border {
            position: relative;
            height: 507px;
            flex: 1;
            background-size: 100% 100%;
            background-image: url('../../assets/img/框@2x.png');
            .charts_title {
                display: flex;
                height: 24px;
                align-items: center;
                position: absolute;
                top: 30px;
                left: 25px;
            }
            .charts_title-icon {
                display: block;
                width: 20px;
                height: 20px;
                background-size: 100% 100%;
                background-image: url('../../assets/img/icon-饼图@2x.png');
            }
            .clumn-icon {
                background-image: url('../../assets/img/icon-柱图@2x.png');
            }
            .charts_title-text {
                margin-left: 5px;
                height: 24px;
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 24px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
    }
}
</style>
